intelmq.bots.collectors.opendxl namespace — intelmq 3.0.0.alpha.1 documentation

# intelmq.bots.collectors.opendxl namespace

## Submodules

## intelmq.bots.collectors.opendxl.collector module

openDXL Collector Bot Connects to a openDXL fabric and subscribes to ATD topic TLS is used by default.

Parameters: dxl_config_file: string dxl_topic: string

`intelmq.bots.collectors.opendxl.collector.` `BOT`

  alias of `intelmq.bots.collectors.opendxl.collector.openDXLCollectorBot`

class `intelmq.bots.collectors.opendxl.collector.` `openDXLCollectorBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.CollectorBot`

  Listen to McAfee openDXL fabric

  `dxl_config_file`: str = None
  `dxl_topic`: str = '/mcafee/event/atd/file/report'
  `init`()
  `process`()
  `shutdown`()

class `intelmq.bots.collectors.opendxl.collector.` `openDXLListener`(dxl_config_file, dxl_topic, object_report, object_send_message, object_logger)

  Bases: `object`

  `start`()
  `stop`()